@@ -1,6 +1,6 @@
 package Outthentic;
 
-our $VERSION = '0.2.22';
+our $VERSION = '0.2.23';
 
 1;
 
@@ -162,9 +162,10 @@ sub run_story_file {
     my $story_dir = get_prop('story_dir');
 
     my $cwd_size = scalar(split /\//, get_prop('project_root_dir'));
+
     my $task_name = get_prop('task_name');
 
-    note("\n". ( nocolor() ? $task_name.short_story_name() : colored(['yellow'],$task_name.short_story_name()) )." started");
+    note("\n". ( nocolor() ? $task_name.'>>'.short_story_name() : colored(['yellow'],$task_name.'>>'.short_story_name()) ));
 
     if ( get_stdout() ){
 
@@ -336,10 +337,13 @@ sub print_meta {
 
     open META, get_prop('story_dir')."/meta.txt" or die $!;
 
-    note( "\n\n". ( nocolor() ? short_story_name() : colored( ['yellow'],  short_story_name() ) )." started\n");
+    my $task_name = get_prop('task_name');
+
+    note( "\n".( nocolor() ? $task_name.'>>'.short_story_name() : colored( ['yellow'],  $task_name.'>>'.short_story_name() ) ));
 
     while (my $i = <META>){
         chomp $i;
+        $i='@ '.$i;
         note( nocolor() ? $i : colored( ['magenta'],  "$i" ));
     }
     close META;
