@@ -4,6 +4,7 @@ package Outthentic::Story;
 use strict;
 use base 'Exporter';
 use Outthentic::DSL;
+use Outthentic::Story::Stat;
 use File::ShareDir;
 use JSON;
 use Carp;
@@ -21,7 +22,7 @@ our @EXPORT = qw{
 
     dsl captures capture stream match_lines
 
-    run_story apply_story_vars story_var
+    run_story apply_story_vars story_var story_vars_pretty
 
     do_perl_hook
 
@@ -38,6 +39,7 @@ our @EXPORT = qw{
     host
 
     dump_os
+
 };
 
 our @stories = ();
@@ -48,8 +50,10 @@ sub new_story {
 
     my $self = {
         ID =>  scalar(@stories),
-        story_vars => {},
-        props => { ignore_story_err => 0 , dsl => Outthentic::DSL->new() },
+        props => { 
+          ignore_story_err => 0 , 
+          dsl => Outthentic::DSL->new() , 
+          story_vars => {} },
     };
 
     push @stories, $self;
@@ -63,6 +67,7 @@ sub end_of_story {
     if (debug_mod12()){
         main::note("end of story: ".(get_prop('story')));
     }
+
     delete $stories[-1];
 
 }
@@ -250,7 +255,10 @@ sub run_story {
 
     my $story_vars = shift || {};
 
-    $main::story_vars = $story_vars;
+    Outthentic::Story::Stat->new_story({
+      vars => $story_vars,
+      path => $path
+    });
 
     my $test_root_dir = get_prop('test_root_dir');
 
@@ -275,6 +283,8 @@ sub run_story {
       }
     }
 
+    # return statistic for downstream story just executed
+    return Outthentic::Story::Stat->current;
 }
 
 sub do_perl_hook {
@@ -555,20 +565,22 @@ sub do_bash_hook {
 
 sub apply_story_vars {
 
-    set_prop( story_vars => $main::story_vars );
+    my $story_vars = Outthentic::Story::Stat->current->{vars};
+
+    set_prop( story_vars =>  $story_vars );
 
     open STORY_VARS, ">", (story_cache_dir())."/variables.json" 
     or die "can't open ".(story_cache_dir())."/variables.json write: $!";
 
-    print STORY_VARS encode_json($main::story_vars);
+    print STORY_VARS encode_json($story_vars);
 
     close STORY_VARS;
 
     open STORY_VARS, ">", (story_cache_dir())."/variables.bash" 
     or die "can't open ".(story_cache_dir())."/variables.bash write: $!";
 
-    for my $name (keys %{$main::story_vars} ){
-      print STORY_VARS "$name=".$main::story_vars->{$name}."\n";
+    for my $name (keys %{$story_vars} ){
+      print STORY_VARS "$name=".$story_vars->{$name}."\n";
     }
 
     close STORY_VARS;
@@ -583,6 +595,12 @@ sub story_var {
 
 }
 
+sub story_vars_pretty {
+
+    join " ", map { "$_:".(story_var($_)) } keys %{get_prop( 'story_vars' ) };
+
+}
+
 sub dump_os {
 
     my $data;
